## Idle Text Editor
![PyPI](https://img.shields.io/pypi/v/idle?style=for-the-badge)
![PyPI - Format](https://img.shields.io/pypi/format/idle?style=for-the-badge)
![PowerShell Gallery](https://img.shields.io/powershellgallery/p/DNS.1.1.1.1?style=for-the-badge)
![PyPI - License](https://img.shields.io/pypi/l/idle?style=for-the-badge)
![Lines of code](https://img.shields.io/tokei/lines/github/devesh01032008/idle?style=for-the-badge)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/devesh01032008/idle?style=for-the-badge)

This is a program written in tkinter which acts as text editor.This can be used to edit file and as alternative of notepad.

### Steps to Download textEditor
```
#For Linux
sudo apt install python3
pip3 install idle

#For Windows
pip install idle

#For macOs
brew install python3
pip install idle
```
It would automatically launch when it is imported in program and nothing is required to launch this program
### How to use it?
```
import idle
# run this command in python Interpretator and this will automatically launch idle display
```

### About The Author

I am Devesh Sharma.I read in class 9. I live in samalkha,panipat located in India.
